import Vue from 'vue'
import Router from 'vue-router'

Vue.use(Router)

/* Layout */
import Layout from '@/layout'

/**
 * Note: sub-menu only appear when route children.length >= 1
 * Detail see: https://panjiachen.github.io/vue-element-admin-site/guide/essentials/router-and-nav.html
 *
 * hidden: true                   if set true, item will not show in the sidebar(default is false)
 * alwaysShow: true               if set true, will always show the root menu
 *                                if not set alwaysShow, when item has more than one children route,
 *                                it will becomes nested mode, otherwise not show the root menu
 * redirect: noRedirect           if set noRedirect will no redirect in the breadcrumb
 * name:'router-name'             the name is used by <keep-alive> (must set!!!)
 * meta : {
    roles: ['admin','editor']    control the page roles (you can set multiple roles)
    title: 'title'               the name show in sidebar and breadcrumb (recommend set)
    icon: 'svg-name'/'el-icon-x' the icon show in the sidebar
    breadcrumb: false            if set false, the item will hidden in breadcrumb(default is true)
    activeMenu: '/example/list'  if set path, the sidebar will highlight the path you set
  }
 */

/**
 * constantRoutes
 * a base page that does not have permission requirements
 * all roles can be accessed
 */
export const constantRoutes = [
  {
    path: '/login',
    component: () => import('@/views/login/index'),
    hidden: true
  },

  {
    path: '/404',
    component: () => import('@/views/404'),
    hidden: true
  },

  {
    path: '/',
    component: Layout,
    redirect: '/dashboard',
    children: [{
      path: 'dashboard',
      name: 'Dashboard',
      component: () => import('@/views/dashboard/index'),
      meta: { title: 'Dashboard', icon: 'dashboard' }
    }]
  },

  {
    path: '/life',
    component: Layout,
    redirect: '/life/warm',
    name: 'life',
    meta: { title: '荟生活', icon: 'el-icon-camera-solid' },
    children: [
      {
        path: 'warm',
        name: 'warm',
        component: () => import('@/views/life/warm'),
        meta: { title: '暖场活动', icon: 'el-icon-position' }
      },
      {
        path: 'warm/detail',
        name: 'warm.detail',
        component: () => import('@/views/life/warm/Detail'),
        meta: { title: '暖场活动详情' },
        hidden: true
      },
      {
        path: 'travel',
        name: 'travel',
        component: () => import('@/views/life/travel'),
        meta: { title: '美好出游季', icon: 'el-icon-bicycle' }
      },
      {
        path: 'travel/detail',
        name: 'travel.detail',
        component: () => import('@/views/life/travel/Detail'),
        meta: { title: '美好出游季详情' },
        hidden: true
      },
      {
        path: 'school',
        name: 'school',
        component: () => import('@/views/life/school'),
        meta: { title: '六点半学堂', icon: 'el-icon-school' }
      },
      {
        path: 'school/detail',
        name: 'school.detail',
        component: () => import('@/views/life/school/Detail'),
        meta: { title: '六点半学堂详情' },
        hidden: true
      },
      {
        path: 'sport',
        name: 'sport',
        component: () => import('@/views/life/sport'),
        meta: { title: '夜跑行动', icon: 'el-icon-moon' }
      },
      {
        path: 'sport/detail',
        name: 'sport.detail',
        component: () => import('@/views/life/sport/Detail'),
        meta: { title: '夜跑行动详情' },
        hidden: true
      },
      {
        path: 'warm-history',
        name: 'warm-history',
        component: () => import('@/views/tree/index'),
        meta: { title: '暖场活动回顾', icon: 'tree' }
      }
    ]
  },

  {
    path: '/rights',
    component: Layout,
    redirect: '/rights/seasons',
    name: 'rights',
    meta: { title: '荟权益', icon: 'el-icon-s-check' },
    children: [
      {
        path: 'seasons',
        name: 'seasons',
        component: () => import('@/views/table/index'),
        meta: { title: '惊喜四季节', icon: 'el-icon-grape' }
      },
      {
        path: 'letter',
        name: 'letter',
        component: () => import('@/views/tree/index'),
        meta: { title: '丽园家书', icon: 'el-icon-notebook-2' }
      }
    ]
  },

  {
    path: '/love',
    component: Layout,
    redirect: '/love/clothes',
    name: 'love',
    meta: { title: '荟爱心', icon: 'el-icon-s-help' },
    children: [
      {
        path: 'clothes',
        name: 'clothes',
        component: () => import('@/views/love/clothes'),
        meta: { title: '旧衣飞行', icon: 'el-icon-aim' }
      },
      {
        path: 'clothes/detail',
        name: 'clothes.detail',
        component: () => import('@/views/love/clothes/Detail'),
        meta: { title: '旧衣飞行详情' },
        hidden: true
      },
      {
        path: 'help',
        name: 'help',
        component: () => import('@/views/love/help'),
        meta: { title: '丽园助农', icon: 'el-icon-bangzhu' }
      },
      {
        path: 'help/detail',
        name: 'help.detail',
        component: () => import('@/views/love/help/Detail'),
        meta: { title: '丽园助农详情' },
        hidden: true
      }
    ]
  },

  {
    path: '/customer',
    component: Layout,
    redirect: '/customer/list',
    name: 'customer',
    meta: { title: '会员管理', icon: 'el-icon-s-custom' },
    children: [
      {
        path: 'list',
        name: 'list',
        component: () => import('@/views/table/index'),
        meta: { title: '信息统计', icon: 'el-icon-data-analysis' }
      },
      {
        path: 'recommender',
        name: 'recommender',
        component: () => import('@/views/tree/index'),
        meta: { title: '推荐记录', icon: 'el-icon-notebook-1' }
      }
    ]
  },

  {
    path: '/form',
    component: Layout,
    children: [
      {
        path: 'index',
        name: 'Form',
        component: () => import('@/views/form/index'),
        meta: { title: 'Form', icon: 'form' }
      }
    ]
  },

  {
    path: '/nested',
    component: Layout,
    redirect: '/nested/menu1',
    name: 'Nested',
    meta: {
      title: 'Nested',
      icon: 'nested'
    },
    children: [
      {
        path: 'menu1',
        component: () => import('@/views/nested/menu1/index'), // Parent router-view
        name: 'Menu1',
        meta: { title: 'Menu1' },
        children: [
          {
            path: 'menu1-1',
            component: () => import('@/views/nested/menu1/menu1-1'),
            name: 'Menu1-1',
            meta: { title: 'Menu1-1' }
          },
          {
            path: 'menu1-2',
            component: () => import('@/views/nested/menu1/menu1-2'),
            name: 'Menu1-2',
            meta: { title: 'Menu1-2' },
            children: [
              {
                path: 'menu1-2-1',
                component: () => import('@/views/nested/menu1/menu1-2/menu1-2-1'),
                name: 'Menu1-2-1',
                meta: { title: 'Menu1-2-1' }
              },
              {
                path: 'menu1-2-2',
                component: () => import('@/views/nested/menu1/menu1-2/menu1-2-2'),
                name: 'Menu1-2-2',
                meta: { title: 'Menu1-2-2' }
              }
            ]
          },
          {
            path: 'menu1-3',
            component: () => import('@/views/nested/menu1/menu1-3'),
            name: 'Menu1-3',
            meta: { title: 'Menu1-3' }
          }
        ]
      },
      {
        path: 'menu2',
        component: () => import('@/views/nested/menu2/index'),
        name: 'Menu2',
        meta: { title: 'menu2' }
      }
    ]
  },

  {
    path: 'external-link',
    component: Layout,
    children: [
      {
        path: 'https://panjiachen.github.io/vue-element-admin-site/#/',
        meta: { title: 'External Link', icon: 'link' }
      }
    ]
  },

  // 404 page must be placed at the end !!!
  { path: '*', redirect: '/404', hidden: true }
]

const createRouter = () => new Router({
  // mode: 'history', // require service support
  scrollBehavior: () => ({ y: 0 }),
  routes: constantRoutes
})

const router = createRouter()

// Detail see: https://github.com/vuejs/vue-router/issues/1234#issuecomment-357941465
export function resetRouter() {
  const newRouter = createRouter()
  router.matcher = newRouter.matcher // reset router
}

export default router
